"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventClient = exports.LogLevel = void 0;
const events_1 = require("../../protoc/events/events");
const hatchet_error_1 = __importDefault(require("../../util/errors/hatchet-error"));
const logger_1 = require("../../util/logger");
const retrier_1 = require("../../util/retrier");
// eslint-disable-next-line no-shadow
var LogLevel;
(function (LogLevel) {
    LogLevel["INFO"] = "INFO";
    LogLevel["WARN"] = "WARN";
    LogLevel["ERROR"] = "ERROR";
    LogLevel["DEBUG"] = "DEBUG";
})(LogLevel || (exports.LogLevel = LogLevel = {}));
class EventClient {
    constructor(config, channel, factory) {
        this.config = config;
        this.client = factory.create(events_1.EventsServiceDefinition, channel);
        this.logger = new logger_1.Logger(`Dispatcher`, config.log_level);
    }
    push(type, input) {
        const req = {
            key: type,
            payload: JSON.stringify(input),
            eventTimestamp: new Date(),
        };
        try {
            const e = this.client.push(req);
            this.logger.info(`Event pushed: ${type}`);
            return e;
        }
        catch (e) {
            throw new hatchet_error_1.default(e.message);
        }
    }
    putLog(stepRunId, log, level) {
        const createdAt = new Date();
        try {
            (0, retrier_1.retrier)(() => __awaiter(this, void 0, void 0, function* () {
                return this.client.putLog({
                    stepRunId,
                    createdAt,
                    message: log,
                    level: level || LogLevel.INFO,
                });
            }), this.logger);
        }
        catch (e) {
            // log a warning, but this is not a fatal error
            this.logger.warn(`Could not put log: ${e.message}`);
        }
    }
}
exports.EventClient = EventClient;
