import * as z from 'zod';
import { Action } from './clients/dispatcher/action-listener';
import { DispatcherClient } from './clients/dispatcher/dispatcher-client';
import { EventClient, LogLevel } from './clients/event/event-client';
import { Logger } from './util/logger';
export declare const CreateStepSchema: z.ZodObject<{
    name: z.ZodString;
    parents: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    timeout: z.ZodOptional<z.ZodString>;
    retries: z.ZodOptional<z.ZodNumber>;
}, "strip", z.ZodTypeAny, {
    name: string;
    parents?: string[] | undefined;
    timeout?: string | undefined;
    retries?: number | undefined;
}, {
    name: string;
    parents?: string[] | undefined;
    timeout?: string | undefined;
    retries?: number | undefined;
}>;
type JSONPrimitive = string | number | boolean | null | Array<JSONPrimitive>;
export type NextStep = {
    [key: string]: NextStep | JSONPrimitive;
};
interface ContextData<T, K> {
    input: T;
    parents: Record<string, any>;
    triggered_by: string;
    user_data: K;
}
export declare class Context<T, K> {
    data: ContextData<T, K>;
    input: T;
    controller: AbortController;
    action: Action;
    client: DispatcherClient;
    eventClient: EventClient;
    overridesData: Record<string, any>;
    logger: Logger;
    constructor(action: Action, client: DispatcherClient, eventClient: EventClient);
    stepOutput(step: string): NextStep;
    triggeredByEvent(): boolean;
    workflowInput(): T;
    userData(): K;
    stepName(): string;
    workflowRunId(): string;
    playground(name: string, defaultValue?: string): string;
    log(message: string, level?: LogLevel): void;
}
export type StepRunFunction<T, K> = (ctx: Context<T, K>) => Promise<NextStep> | NextStep | void;
export interface CreateStep<T, K> extends z.infer<typeof CreateStepSchema> {
    run: StepRunFunction<T, K>;
}
export {};
