"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Context = exports.CreateStepSchema = void 0;
const hatchet_error_1 = __importDefault(require("./util/errors/hatchet-error"));
const z = __importStar(require("zod"));
const workflow_1 = require("./workflow");
const logger_1 = require("./util/logger");
const parse_1 = require("./util/parse");
exports.CreateStepSchema = z.object({
    name: z.string(),
    parents: z.array(z.string()).optional(),
    timeout: workflow_1.HatchetTimeoutSchema.optional(),
    retries: z.number().optional(),
});
class Context {
    constructor(action, client, eventClient) {
        this.controller = new AbortController();
        this.overridesData = {};
        try {
            const data = (0, parse_1.parseJSON)(action.actionPayload);
            this.data = data;
            this.action = action;
            this.client = client;
            this.eventClient = eventClient;
            this.logger = new logger_1.Logger(`Context Logger`, client.config.log_level);
            // if this is a getGroupKeyRunId, the data is the workflow input
            if (action.getGroupKeyRunId !== '') {
                this.input = data;
            }
            else {
                this.input = data.input;
            }
            this.overridesData = data.overrides || {};
        }
        catch (e) {
            throw new hatchet_error_1.default(`Could not parse payload: ${e.message}`);
        }
    }
    stepOutput(step) {
        if (!this.data.parents) {
            throw new hatchet_error_1.default('Step output not found');
        }
        if (!this.data.parents[step]) {
            throw new hatchet_error_1.default(`Step output for '${step}' not found`);
        }
        return this.data.parents[step];
    }
    triggeredByEvent() {
        var _a;
        return ((_a = this.data) === null || _a === void 0 ? void 0 : _a.triggered_by) === 'event';
    }
    workflowInput() {
        return this.input;
    }
    userData() {
        var _a;
        return (_a = this.data) === null || _a === void 0 ? void 0 : _a.user_data;
    }
    stepName() {
        return this.action.stepName;
    }
    workflowRunId() {
        return this.action.workflowRunId;
    }
    playground(name, defaultValue = '') {
        if (name in this.overridesData) {
            return this.overridesData[name];
        }
        this.client.putOverridesData({
            stepRunId: this.action.stepRunId,
            path: name,
            value: JSON.stringify(defaultValue),
        });
        return defaultValue;
    }
    log(message, level) {
        const { stepRunId } = this.action;
        if (!stepRunId) {
            // log a warning
            this.logger.warn('cannot log from context without stepRunId');
            return;
        }
        this.eventClient.putLog(stepRunId, message, level);
    }
}
exports.Context = Context;
